package name.lamperi.orbital

import java.io.File

data class Problem (
        val seed : Double, val satellites : Set<Satellite>, val route : Route)

data class Satellite (
        val id : String, val lat : Double, val lon : Double, val height : Double)

data class Route (
        val startLat : Double, val startLon : Double, val endLat : Double, val endLon : Double)

fun parseFile(file : File) : Problem {
    val contents : String = file.readText()
    val seed : Double = contents.splitToSequence('\n').first().splitToSequence(':').last().toDouble()
    val satellites : Set<Satellite> =  contents.splitToSequence('\n')
            .filter { it.startsWith("SAT") }
            .map {
                val parts = it.split(',')
                Satellite(id = parts[0], lat = parts[1].toDouble(),
                        lon = parts[2].toDouble(), height = parts[3].toDouble())
            }.toSet()
    val route : Route = contents.splitToSequence('\n')
            .filter { it.startsWith("ROUTE") }
            .map {
                val parts = it.split(',')
                Route(startLat = parts[1].toDouble(), startLon = parts[2].toDouble(),
                        endLat = parts[3].toDouble(), endLon = parts[4].toDouble())
            }.first()
    return Problem(seed = seed, satellites = satellites, route = route)
}